@@ -1,5 +1,5 @@
 """
- * $Id: 1.1+9 utils.py 2b62b6eac4a1 2021-06-18 od $
+ * $Id: 1.1+11 utils.py de8100d559ad 2021-06-25 od $
  *
  * This file is part of the Cloud Services Integration Platform (CSIP),
  * a Model-as-a-Service framework, API and application suite.
@@ -105,6 +105,13 @@ class Client(object):
             data = json.load(f)
         return data
 
+
+    @staticmethod
+    def save_json(file: str, js: Dict) -> None:
+        """Save a dict to a file"""
+        with open(file, 'w') as outfile:
+            json.dump(js, outfile, indent=2)
+
     @staticmethod
     def __create_dict(json: List[Dict]) -> Dict:
         """Create dict key:name, value: whole json"""
@@ -460,9 +467,9 @@ class Client(object):
                 files.append(name)
         return files
 
-    def download_data_files(self, files: List[str] = None, dir: str = ".", conf: Dict = None) -> None:
+    def download_data_files(self, files: List[str] = None, dir: str = ".", prefix: str = '', conf: Dict = None) -> None:
         """ Downloads file(s) if this Client object is a valid response and a query url as value.
-            If no 'file' argument is provided, all files will be dowloaded.
+            If no 'file' argument is provided, all files will be downloaded.
             If no 'dir' is provided, the current directory will be used.
         """
         if files is None or not files:
@@ -484,7 +491,7 @@ class Client(object):
             print("  --> " + name)
             response, http_status = Client.__get0(val, conf)
             if http_status == 200:
-                with open(os.path.join(dir, name), 'wb') as outfile:
+                with open(os.path.join(dir, prefix + name), 'wb') as outfile:
                     outfile.write(response.content)
             else:
                 raise Exception("Error downloading : " + val)
